#!/bin/bash
#
# Create a proxy using cert1. 
# Create a directory in the catalog.
# Create an entry in that directory. 
# Set delete permissions only for owner.
# Destroy proxy for cert1. 
# Create a proxy using cert2.
# Use cert2 proxy to delete the file. 
# Check that using cert2 proxy I cannot delete the file.
# Create a proxy using cert1.
# Delete the file and directory created.
#
##########################################################################
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://eu-egee.org/partners/ for details on the copyright holders.
# For license conditions see the license file 
# http://eu-egee.org/license.html
#
#########################################################################
# Author: David Collados
# $Id: test_catalog_permission_delete.sh,v 1.4 2005/06/06 14:40:17 dcollado Exp $
# 
#
# Usage: test_catalog_permission_delete.sh [-d directory_name][-f file_name]
# [-c1 usercert_path1][-k1 userkey_path1][-c2 usercert_path2][-k2 userkey_path2]
# [-p proxy_file][-o vo_name][-s secure_endpoint][-v][-h]
#
# -d  directory_name   Directory to create in the catalog.
# -f  file_name        File to create in the catalog directory.
# -c1 usercert_path1   Path to usercert.pem for certificate1.
# -k1 userkey_path1    Path to userkey.pem for certificate1.
# -c2 usercert_path2   Path to usercert.pem for certificate2.
# -k2 userkey_path2    Path to userkey.pem for certificate2.
# -p  proxy_file       Path to the generated proxy using voms-proxy-init.
# -o  vo_name          VO name.
# -s  secure_endpoint  Secure endpoint for Catalog.
# -v                   Verbose.
# -h                   Print this message.
#
###############################################################################
# Beginning of functions definitions
###############################################################################
#
function usage()
{
    cat <<EOF

usage: `basename $0` [-d directory_name][-f file_name][-c1 usercert_path1][-k1 userkey_path1][-c2 usercert_path2][-k2 userkey_path2][-p proxy_file][-o vo_name][-s secure_endpoint][-v][-h]

Create a proxy using cert1. 
Create a directory in the catalog. 
Create an entry in that directory. 
Set delete permissions only for owner.
Destroy proxy for cert1. 
Create a proxy using cert2. 
Use cert2 proxy to delete the file. 
Check that using cert2 proxy I cannot delete the file.
Create a proxy using cert1.
Delete the file and directory created.

-d  directory_name        Directory to create in the catalog.
-f  file_name             File to create in the catalog directory.
-c1 usercert_path1        Path to usercert.pem for certificate1.
-k1 userkey_path1         Path to userkey.pem for certificate1.
-c2 usercert_path2        Path to usercert.pem for certificate2.
-k2 userkey_path2         Path to userkey.pem for certificate2.
-p  proxy_file            Path to the generated proxy using voms-proxy-init.
-o  vo_name               VO name. 
-s  secure_endpoint       Secure endpoint for Catalog.
-v                        Verbose.
-h                        Print this message.

EOF
} 

###############################################################################
# End of function definitions
###############################################################################

###############################################################################
# Main program begins here!
###############################################################################

# Verbose and debug options are off by default
verbose=0
debug=0

CONF_FILE=$GLITE_LOCATION/test/etc/glite-data-catalog-fireman/test_catalog_permission.conf
if [ -r $GLITE_LOCATION/test/etc/glite-data-catalog-fireman/test_catalog_permission.conf ]; then
	source ${CONF_FILE}
else
	echo "cannot find configuration file " ${CONF_FILE}
	exit 1
fi

#Parse command line options
while getopts d:f:c1:k1:c2:k2:p:o:s:vh opt
do
   case "$opt" in
      d) DIR_NAME=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Directory to create in the catalog: " $DIR_NAME
         fi
         ;;
      f) FILE_NAME=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "File to create in the catalog directory: " $FILE_NAME
         fi
         ;;
      c1) USER_CERT1=$OPTARG
         if [ $verbose -eq 1 ]; then 
            echo "Path to usercert.pem for certificate 1: " $USER_CERT1
         fi
         ;;
      k1) USER_KEY1=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Path to userkey.pem for certificate 1: " $USER_KEY1
         fi
         ;;
      c2) USER_CERT2=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Path to usercert.pem for certificate 2: " $USER_CERT2
         fi
         ;;
      k2) USER_KEY2=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Path to userkey.pem for certificate 2: " $USER_KEY2
         fi
         ;;
      p) PROXY_FILE=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Path to the generated proxy using voms-proxy-init: " $PROXY_FILE
         fi
         ;;
      o) VO_NAME=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "VO name: " $VO_NAME
         fi
         ;;
      s) CATALOG_ENDPOINT=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Secure Catalog endpoint: " $CATALOG_ENDPOINT
         fi
         ;;
      v) verbose=1
         ;;
      h) usage
         exit 0
         ;;
   esac
done

if [ -z "$DIR_NAME" ]; then
    echo "error: directory_name not defined!"
    usage
    exit 1
fi

if [ -z "$FILE_NAME" ]; then
    echo "error: file_name not defined!"
    usage
    exit 1
fi

if [ -z "$USER_CERT1" ]; then
    echo "error: Path to usercert.pem for certificate1 not defined!"
    usage
    exit 1
fi

if [ -z "$USER_KEY1" ]; then
    echo "error: Path to userkey.pem for certificate1 not defined!"
    usage
    exit 1
fi

if [ -z "$USER_CERT2" ]; then
    echo "error: Path to usercert.pem for certificate2 not defined!"
    usage
    exit 1
fi

if [ -z "$USER_KEY2" ]; then
    echo "error: Path to userkey.pem for certificate2 not defined!"
    usage
    exit 1
fi

if [ -z "$PROXY_FILE" ]; then
    echo "error: Path to proxy file not defiled!!"
    usage
    exit 1
fi

if [ -z "$VO_NAME" ]; then
    echo "error: VO name not defined!"
    usage
    exit 1
fi

if [ -z "$CATALOG_ENDPOINT" ]; then
    echo "error: Endpoint for a secure catalog not defined!"
    usage
    exit 1
fi


#create proxy for certificate1
echo "Creating proxy for certificate 1..."
voms-proxy-init -cert $USER_CERT1 -key $USER_KEY1 -voms $VO_NAME 
if [ $? -ne 0 ]; then
    echo "glite-proxy-init -cert $USER_CERT1 -key $USER_KEY1 -voms $VO_NAME command failed. Exiting..."
    exit 2
fi
echo ""


#to create a dedicated directory in the catalogue
echo "Creating directory $DIR_NAME using catalog endpoint $CATALOG_ENDPOINT"
glite-catalog-mkdir $DIR_NAME -s $CATALOG_ENDPOINT > /tmp/tmp.catalog 2>&1
if [ $? -ne 0 ]; then
	 if [ `grep -c "aready" /tmp/tmp.catalog` -ne 1 ]; then
		  echo "glite-catalog-mkdir command failed, exiting"
		  exit 2
	 else
		  echo "directory " $DIR_NAME "already exists"
         fi
else	  
	 echo "glite-catalog-mkdir created directory " $DIR_NAME
fi
rm -f /tmp/tmp.catalog
echo ""


#to create an entry in the directory
echo "Creating entry $DIR_NAME/$FILE_NAME in the catalog..."
glite-catalog-create -s $CATALOG_ENDPOINT -v $DIR_NAME/$FILE_NAME 
if [ $? -ne 0 ]; then
    echo "glite-catalog-create command failed. Exiting..."
    exit 2
fi
echo ""


echo "Checking if the entry is now in the catalog..."
glite-catalog-ls -l -v -g -s $CATALOG_ENDPOINT $DIR_NAME
if [ $? -ne 0 ]; then
	 echo "glite-catalog-ls command failed. Exiting"
	 exit 2
fi
echo ""


#Set permissions to delete only the owner
echo "Set permission to delete only for the owner..."
glite-catalog-chmod -s $CATALOG_ENDPOINT -v u=pdrwlxgs,go=prwlxgs $DIR_NAME/$FILE_NAME
if [ $? -ne 0 ]; then
         echo "glite-catalog-chmod -s $CATALOG_ENDPOINT -v u=pdrwlxgs,go=prwlxgs $DIR_NAME/$FILE_NAME command failed. Exiting"
         exit 2
fi
echo ""


#check that entry was created in the catalog
echo "Checking again the entry in the catalog with new permissions only for owner..."
glite-catalog-ls -l -v -g -s $CATALOG_ENDPOINT $DIR_NAME/$FILE_NAME
if [ $? -ne 0 ]; then
         echo "glite-catalog-ls -l -v -g -s $CATALOG_ENDPOINT $DIR_NAME/$FILE_NAME command failed. Exiting"
         exit 2
fi
echo ""


#destroy proxy for certificate1
echo "Destroying proxy $PROXY_FILE for certificate 1..."
voms-proxy-destroy -debug -file $PROXY_FILE
if [ $? -ne 0 ]; then
    echo "voms-proxy-destroy -debug -file $PROXY_FILE command failed. Exiting..."
    exit 2
fi
echo ""


#create proxy for certificate2
echo "Creating proxy for certificate 2..."
voms-proxy-init -cert $USER_CERT2 -key $USER_KEY2 -voms $VO_NAME
if [ $? -ne 0 ]; then
    echo "glite-proxy-init -cert $USER_CERT2 -key $USER_KEY2 -voms $VO_NAME command failed. Exiting..."
    exit 2
fi
echo ""


#trying to delete the entry using certificate2
echo "Trying to delete the entry using certificate 2..."
echo "glite-catalog-rm -s $CATALOG_ENDPOINT -v $DIR_NAME/$FILE_NAME"
glite-catalog-rm -s $CATALOG_ENDPOINT -v $DIR_NAME/$FILE_NAME
if [ $? -eq 0 ]; then
         #create again proxy for certificate1
         echo ""
         echo "Creating proxy for certificate 1..."
         voms-proxy-init -cert $USER_CERT1 -key $USER_KEY1 -voms $VO_NAME
         if [ $? -ne 0 ]; then
             echo "glite-proxy-init -cert $USER_CERT1 -key $USER_KEY1 -voms $VO_NAME command failed. Exiting..."
             exit 2
         fi

         # Remove directory and file created
         echo ""
         echo "Removing directory and file created..."
         echo "glite-catalog-rm -s $CATALOG_ENDPOINT -v -r $DIR_NAME"
         glite-catalog-rm -s $CATALOG_ENDPOINT -v -r $DIR_NAME
         if [ $? -ne 0 ]; then
             echo "glite-catalog-rm -s $CATALOG_ENDPOINT -v -r $DIR_NAME command failed. Exiting..."
             exit 2
         fi

         # Display test result
         echo ""
         echo "TEST FAILED: Could delete $DIR_NAME/$FILE_NAME entry using certificate 2..."
         echo ""
         exit 2
else
         #create again proxy for certificate1
         echo ""
         echo "Creating proxy for certificate 1..."
         voms-proxy-init -cert $USER_CERT1 -key $USER_KEY1 -voms $VO_NAME
         if [ $? -ne 0 ]; then
             echo "glite-proxy-init -cert $USER_CERT1 -key $USER_KEY1 -voms $VO_NAME command failed. Exiting..."
             exit 2
         fi

         # Remove directory and file created
         echo ""
         echo "Removing directory and file created..."
         echo "glite-catalog-rm -s $CATALOG_ENDPOINT -v -r $DIR_NAME"
         glite-catalog-rm -s $CATALOG_ENDPOINT -v -r $DIR_NAME
         if [ $? -ne 0 ]; then
             echo "glite-catalog-rm -s $CATALOG_ENDPOINT -v -r $DIR_NAME command failed. Exiting..."
             exit 2
         fi

         # Display test result
         echo ""
         echo "TEST PASSED"
         echo ""
fi

exit 0;

